Fit a Bayesian semiparametric PH model with random intercept and random treatment for clustered general interval-censored data. Each random effect follows a Dirichlet process mixture distribution.
clusterIC_trt_DP(L, R, y, xcov, IC, scale.designX, scaled, xtrt, area, binary,
I, order, knots, grids, a_eta, b_eta, a_ga, b_ga, a_alpha, b_alpha, H,
a_tau_star, b_tau_star, a_alpha_trt, b_alpha_trt, H_trt, a_tau_trt_star,
b_tau_trt_star, beta_iter, phi_iter, beta_cand, phi_cand, beta_sig0, x_user,
total, burnin, thin, conf.int, seed)The vector of left endpoints of the observed time intervals.
The vector of right endponts of the observed time intervals.
The vector of censoring indicator: 0=left-censored, 1=interval-censored, 2=right-censored.
The covariate matrix for the p predictors.
The vector of general interval-censored indicator: 1=general interval-censored, 0=exact.
The TRUE or FALSE indicator of whether or not to scale the design matrix X.
The vector indicating whether each covariate is to be scaled: 1=to be scaled, 0=not.
The covariate that has a random effect.
The vector of cluster ID.
The vector indicating whether each covariate is binary.
The number of clusters.
The degree of basis I-splines: 1=linear, 2=quadratic, 3=cubic, etc.
A sequence of knots to define the basis I-splines.
A sequence of points at which baseline survival function is to be estimated.
The shape parameter of Gamma prior for gamma_l.
The rate parameter of Gamma prior for gamma_l.
The shape parameter of Gamma prior for e^{beta_r}.
The rate parameter of Gamma prior for e^{beta_r}.
The shape parameter of Gamma prior for alpha.
The rate parameter of Gamma prior for alpha.
The number of distinct components in DP mixture prior under blocked Gibbs sampler.
The shape parameter of G_0 in DP mixture prior.
The rate parameter of G_0 in DP mixture prior.
The shape parameter of Gamma prior for alpha_trt.
The rate parameter of Gamma prior for alpha_trt.
The number of distinct components in DP mixture prior under blocked Gibbs sampler for random treatment.
The shape parameter of G_0 in DP mixture prior for random treatment.
The rate parameter of G_0 in DP mixture prior for random treatment.
The number of initial iterations in the Metropolis-Hastings sampling for beta_r.
The number of initial iterations in the Metropolis-Hastings sampling for phi_i.
The sd of the proposal normal distribution in the initial MH sampling for beta_r.
The sd of the proposal normal distribution in the initial MH sampling for phi_i.
The sd of the prior normal distribution for beta_r.
The user-specified covariate vector at which to estimate survival function(s).
The number of total iterations.
The number of burnin.
The frequency of thinning.
The confidence level of the CI for beta_r.
A user-specified random seed.
a list containing the following elements:
The sample size.
A total by p matrix of MCMC draws of beta_r, r=1, ..., p.
A total by length(grids) matrix, each row contains
the baseline survival at grids from one iteration.
A total by length(grids)*G matrix, each row contains
the survival at grids from one iteration.
G is the number of sets of user-specified covariate values.
A total by 1 vector of MCMC draws of alpha.
A total by 1 vector of MCMC draws of alpha_trt.
A total by I matrix of MCMC draws of phi_i, i=1,...,I.
A total by I matrix of MCMC draws of phi_trt_i, i=1,...,I.
A total by H matrix of MCMC draws of tau_star.
A total by H_trt matrix of MCMC draws of tau_trt_star.
A vector of regression coefficient estimates.
A vector of sample standard deviations of regression coefficient estimates.
The credible intervals for the regression coefficients.
The estimated baseline survival at grids.
The estimated survival at grids with user-specified covariate values x_user.
The sequance of points where baseline survival function is estimated.
Deviance information criterion.
Negative log pseudo-marginal likelihood.
Both random intercept and random treatment follow its own DP mixture prior. DP mixture prior:
phi_i~N(0,tau_{i}^{-1})
tau_{i}~G
G~DP(alpha,G_{0})
G_{0}=Gamma(a_tau_star,b_tau_star)
tau_{h}^{*}~G_{0}, h=1,...,H
The blocked Gibbs sampler proposed by Ishwaran and James (2001) is used to sample from the posteriors under the DP mixture prior.